aboutsummaryrefslogtreecommitdiffhomepage
path: root/crates/shirabe/src/plugin/plugin_manager.rs
diff options
context:
space:
mode:
Diffstat (limited to 'crates/shirabe/src/plugin/plugin_manager.rs')
-rw-r--r--crates/shirabe/src/plugin/plugin_manager.rs11
1 files changed, 7 insertions, 4 deletions
diff --git a/crates/shirabe/src/plugin/plugin_manager.rs b/crates/shirabe/src/plugin/plugin_manager.rs
index 04c53d08..bc434262 100644
--- a/crates/shirabe/src/plugin/plugin_manager.rs
+++ b/crates/shirabe/src/plugin/plugin_manager.rs
@@ -434,10 +434,13 @@ impl PluginManager {
let path = class_loader.find_file(&class).unwrap_or_else(|| {
panic!("plugin class `{class}` is already defined but has no autoloadable file")
});
- // TODO(bytes): file_get_contents is lossy UTF-8; the eval'd plugin source
- // should be carried as bytes.
- let code = file_get_contents(&path)
- .unwrap_or_else(|| panic!("unable to read the plugin class file `{path}`"));
+ // TODO(bytes): the eval'd plugin source is carried as a String, so
+ // from_utf8_lossy corrupts a source file that is not valid UTF-8.
+ let code =
+ String::from_utf8_lossy(&file_get_contents(&path).unwrap_or_else(|_| {
+ panic!("unable to read the plugin class file `{path}`")
+ }))
+ .into_owned();
let class_counter = CLASS_COUNTER.load(std::sync::atomic::Ordering::Relaxed);
let separator_pos = strrpos(&class, "\\");
let mut class_name = class.clone();